..
    This file is part of COUNTER-Robots.
    Copyright (C) 2018 CERN.

    COUNTER-Robots is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


.. include:: ../README.rst

User's Guide
------------

This part of the documentation will show you how to get started in using
COUNTER-Robots.

.. toctree::
   :maxdepth: 2

   installation
   usage


Additional Notes
----------------

Notes on how to contribute, legal information and changes are here for the
interested.

.. toctree::
   :maxdepth: 1

   contributing
   changes
   license
   authors
